aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/module.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/module.cxx')
-rw-r--r--libbuild2/module.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/libbuild2/module.cxx b/libbuild2/module.cxx
index a55a1a6..1bd60a6 100644
--- a/libbuild2/module.cxx
+++ b/libbuild2/module.cxx
@@ -155,12 +155,12 @@ namespace build2
assert (*ctx.module_context_storage == nullptr);
// Since we are using the same scheduler, it makes sense to reuse the
// same mutex shards. Also disable nested module context for good
// measure.
//
ctx.module_context_storage->reset (
new context (ctx.sched,
- ctx.mutex_shards,
+ ctx.mutexes,
false, /* dry_run */
ctx.keep_going,
ctx.global_var_overrides, /* cmd_vars */
@@ -155,12 +155,12 @@ namespace build2
assert (*ctx.module_context_storage == nullptr);
// Since we are using the same scheduler, it makes sense to reuse the
- // same mutex shards. Also disable nested module context for good
+ // same global mutexes. Also disable nested module context for good
// measure.
//